==> zio-aws-mediapackagev2_2.12-7.21.15.1-sources.jar: zio/aws/mediapackagev2/model/CreateChannelGroupResponse.scala <==
package zio.aws.mediapackagev2.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.mediapackagev2.model.primitives.{
  TagValue,
  TagKey,
  ResourceDescription,
  Timestamp
}
import scala.jdk.CollectionConverters._
final case class CreateChannelGroupResponse(
    channelGroupName: String,
    arn: String,
    egressDomain: String,
    createdAt: Timestamp,
    modifiedAt: Timestamp,
    description: Optional[ResourceDescription] = Optional.Absent,
    tags: Optional[Map[TagKey, TagValue]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackagev2.model.CreateChannelGroupResponse = {
    import CreateChannelGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackagev2.model.CreateChannelGroupResponse
      .builder()
      .channelGroupName(channelGroupName: java.lang.String)
      .arn(arn: java.lang.String)
      .egressDomain(egressDomain: java.lang.String)
      .createdAt(Timestamp.unwrap(createdAt): Instant)
      .modifiedAt(Timestamp.unwrap(modifiedAt): Instant)
      .optionallyWith(
        description.map(value =>
          ResourceDescription.unwrap(value): java.lang.String
        )
      )(_.description)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (TagKey.unwrap(key): java.lang.String) -> (TagValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly
      : zio.aws.mediapackagev2.model.CreateChannelGroupResponse.ReadOnly =
    zio.aws.mediapackagev2.model.CreateChannelGroupResponse
      .wrap(buildAwsValue())
}
object CreateChannelGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackagev2.model.CreateChannelGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackagev2.model.CreateChannelGroupResponse =
      zio.aws.mediapackagev2.model.CreateChannelGroupResponse(
        channelGroupName,
        arn,
        egressDomain,
        createdAt,
        modifiedAt,
        description.map(value => value),
        tags.map(value => value)
      )
    def channelGroupName: String
    def arn: String
    def egressDomain: String
    def createdAt: Timestamp
    def modifiedAt: Timestamp
    def description: Optional[ResourceDescription]
    def tags: Optional[Map[TagKey, TagValue]]
    def getChannelGroupName: ZIO[Any, Nothing, String] =
      ZIO.succeed(channelGroupName)
    def getArn: ZIO[Any, Nothing, String] = ZIO.succeed(arn)
    def getEgressDomain: ZIO[Any, Nothing, String] = ZIO.succeed(egressDomain)
    def getCreatedAt: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(createdAt)
    def getModifiedAt: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(modifiedAt)
    def getDescription: ZIO[Any, AwsError, ResourceDescription] =
      AwsError.unwrapOptionField("description", description)
    def getTags: ZIO[Any, AwsError, Map[TagKey, TagValue]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackagev2.model.CreateChannelGroupResponse
  ) extends zio.aws.mediapackagev2.model.CreateChannelGroupResponse.ReadOnly {
    override val channelGroupName: String = impl.channelGroupName(): String
    override val arn: String = impl.arn(): String
    override val egressDomain: String = impl.egressDomain(): String
    override val createdAt: Timestamp =
      zio.aws.mediapackagev2.model.primitives.Timestamp(impl.createdAt())
    override val modifiedAt: Timestamp =
      zio.aws.mediapackagev2.model.primitives.Timestamp(impl.modifiedAt())
    override val description: Optional[ResourceDescription] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value =>
          zio.aws.mediapackagev2.model.primitives.ResourceDescription(value)
        )
    override val tags: Optional[Map[TagKey, TagValue]] = zio.aws.core.internal
      .optionalFromNullable(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.mediapackagev2.model.primitives.TagKey(
              key
            ) -> zio.aws.mediapackagev2.model.primitives.TagValue(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackagev2.model.CreateChannelGroupResponse
  ): zio.aws.mediapackagev2.model.CreateChannelGroupResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediapackagev2_3-7.21.15.3-sources.jar: zio/aws/mediapackagev2/model/CreateChannelGroupResponse.scala <==
package zio.aws.mediapackagev2.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.mediapackagev2.model.primitives.{
  TagValue,
  TagKey,
  ResourceDescription,
  Timestamp
}
import scala.jdk.CollectionConverters.*
final case class CreateChannelGroupResponse(
    channelGroupName: String,
    arn: String,
    egressDomain: String,
    createdAt: Timestamp,
    modifiedAt: Timestamp,
    description: Optional[ResourceDescription] = Optional.Absent,
    tags: Optional[Map[TagKey, TagValue]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackagev2.model.CreateChannelGroupResponse = {
    import CreateChannelGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackagev2.model.CreateChannelGroupResponse
      .builder()
      .channelGroupName(channelGroupName: java.lang.String)
      .arn(arn: java.lang.String)
      .egressDomain(egressDomain: java.lang.String)
      .createdAt(Timestamp.unwrap(createdAt): Instant)
      .modifiedAt(Timestamp.unwrap(modifiedAt): Instant)
      .optionallyWith(
        description.map(value =>
          ResourceDescription.unwrap(value): java.lang.String
        )
      )(_.description)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (TagKey.unwrap(key): java.lang.String) -> (TagValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .build()
  }
  def asReadOnly
      : zio.aws.mediapackagev2.model.CreateChannelGroupResponse.ReadOnly =
    zio.aws.mediapackagev2.model.CreateChannelGroupResponse
      .wrap(buildAwsValue())
}
object CreateChannelGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackagev2.model.CreateChannelGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackagev2.model.CreateChannelGroupResponse =
      zio.aws.mediapackagev2.model.CreateChannelGroupResponse(
        channelGroupName,
        arn,
        egressDomain,
        createdAt,
        modifiedAt,
        description.map(value => value),
        tags.map(value => value)
      )
    def channelGroupName: String
    def arn: String
    def egressDomain: String
    def createdAt: Timestamp
    def modifiedAt: Timestamp
    def description: Optional[ResourceDescription]
    def tags: Optional[Map[TagKey, TagValue]]
    def getChannelGroupName: ZIO[Any, Nothing, String] =
      ZIO.succeed(channelGroupName)
    def getArn: ZIO[Any, Nothing, String] = ZIO.succeed(arn)
    def getEgressDomain: ZIO[Any, Nothing, String] = ZIO.succeed(egressDomain)
    def getCreatedAt: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(createdAt)
    def getModifiedAt: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(modifiedAt)
    def getDescription: ZIO[Any, AwsError, ResourceDescription] =
      AwsError.unwrapOptionField("description", description)
    def getTags: ZIO[Any, AwsError, Map[TagKey, TagValue]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackagev2.model.CreateChannelGroupResponse
  ) extends zio.aws.mediapackagev2.model.CreateChannelGroupResponse.ReadOnly {
    override val channelGroupName: String = impl.channelGroupName(): String
    override val arn: String = impl.arn(): String
    override val egressDomain: String = impl.egressDomain(): String
    override val createdAt: Timestamp =
      zio.aws.mediapackagev2.model.primitives.Timestamp(impl.createdAt())
    override val modifiedAt: Timestamp =
      zio.aws.mediapackagev2.model.primitives.Timestamp(impl.modifiedAt())
    override val description: Optional[ResourceDescription] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value =>
          zio.aws.mediapackagev2.model.primitives.ResourceDescription(value)
        )
    override val tags: Optional[Map[TagKey, TagValue]] = zio.aws.core.internal
      .optionalFromNullable(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.mediapackagev2.model.primitives.TagKey(
              key
            ) -> zio.aws.mediapackagev2.model.primitives.TagValue(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackagev2.model.CreateChannelGroupResponse
  ): zio.aws.mediapackagev2.model.CreateChannelGroupResponse.ReadOnly =
    new Wrapper(impl)
}
